==> dingtalk-cli-pro-0.0.6.tgz: package/lib/cli.js <==
const signale = require('signale');
const semver = require('semver');
const path = require('path')
const lodash = require('lodash');
const client = require('./core');
const config = JSON.parse(process.env.config);
const debug = require('debug')(`client:cli`)
// Notify update when process exits
const updater = require('update-notifier');
const pkg = require('../package.json');
const cwd = process.cwd();
updater({ pkg }).notify({ defer: true });

let clientConfig = lodash.merge({ pluginPath: ''}, pkg[config.brandName])

if (client.fs.exists(path.join(cwd, `.${config.brandName}rc.js`))) {
  lodash.merge(clientConfig, require(path.resolve(cwd, `.${config.brandName}rc.js`)));
} else if (client.fs.exists(path.join(cwd, `${config.brandName}rc.js`))) {
  lodash.merge(clientConfig, require(path.resolve(cwd, `${config.brandName}rc.js`)));
}else if (client.fs.readJSON(path.join(cwd, `.${config.brandName}rc`))) {
  lodash.merge(clientConfig, client.fs.readJSON(path.join(cwd, `.${config.brandName}rc`)));
}


// Node version check
const nodeVersion = process.versions.node;
if (semver.satisfies(nodeVersion, '< 8.9')) {
  signale.error(`Node version must >= 8.9, but got ${nodeVersion}`);
  process.exit(1);
}

// execute system plugin: install, list, publish, dev
client.executeSystemPlugin();
// loader installed plugin from system folder
client.loaderInstalledPlugin(config.npmRoot);
// loader point plugins from config
debug(`.rc config: %o`, clientConfig);
if (clientConfig.pluginPath) {
  client.loaderConfigPluginDir(path.resolve(cwd, clientConfig.pluginPath));
} 

if (clientConfig.plugins && clientConfig.plugins.length && lodash.isArray(clientConfig.plugins)) {
  client.loaderConfigPluginFiles(clientConfig.plugins, cwd);
}


// parse argv 
client.program.parse(process.argv);

==> dingtalk-cli-pro-0.0.40.tgz: package/lib/cli.js <==
const signale = require('signale');
const semver = require('semver');
const path = require('path')
const lodash = require('lodash');
const client = require('./core');
const config = require('../bin/config');
const debug = require('debug')(`dingtalk-cli-pro:cli`)
const updater = require('update-notifier');
const chalk = require('chalk');
const pkg = require('../package.json');
const spawn = require('./util/spawn-command');
const cwd = process.cwd();

// 检查版本，每隔个小时
updater({ pkg, updateCheckInterval: config.UPDATE_CHECK_INTERVAL} ).notify({ defer: true });
// Node version check
const nodeVersion = process.versions.node;
if (semver.satisfies(nodeVersion, '< 8.9')) {
  signale.error(`Node version must >= 8.9, but got ${nodeVersion}`);
  process.exit(1);
}


// execute system plugin: install, list, publish, dev
client.loaderInstalledPlugin(path.resolve(config.npmRoot, './node_modules'));
client.executeSystemPlugin();

let clientConfig = lodash.merge({ pluginPath: ''}, pkg[config.brandName])

if (client.fs.exists(path.join(cwd, `.${config.brandName}rc.js`))) {
  lodash.merge(clientConfig, require(path.resolve(cwd, `.${config.brandName}rc.js`)));
} else if (client.fs.exists(path.join(cwd, `${config.brandName}rc.js`))) {
  lodash.merge(clientConfig, require(path.resolve(cwd, `${config.brandName}rc.js`)));
} else if (client.fs.readJSON(path.join(cwd, `.${config.brandName}rc`))) {
  lodash.merge(clientConfig, client.fs.readJSON(path.join(cwd, `.${config.brandName}rc`)));
}
// loader installed plugin from system folder
client.loaderInstalledPlugin(config.npmRoot);
// loader point plugins from config

if (clientConfig.plugins && clientConfig.plugins.length && lodash.isArray(clientConfig.plugins)) {
  client.loaderConfigPluginFiles(clientConfig.plugins, cwd);
}



// parse argv 
client.program
.version(pkg.version)
.on('command:*', () => {
  console.log(`${client.randomEmoji()}  Invalid command: ${chalk.red(client.program.args.join(' '))} \n See --help for a list of available commands.`);
  process.exit(1);
})
.parse(process.argv);
